figaro.likelihood
=================

.. automodule:: figaro.likelihood

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      eval_mix
      eval_mix_1d
      evaluate_mixture_MC_draws
      evaluate_mixture_MC_draws_1d
      inv_jit
      log_norm
      log_norm_1d
      log_norm_int
      logdet_jit
      logsumexp_jit
      scalar_product
   
   

   
   
   

   
   
   



